@@ -1,7 +1,7 @@
 package Carmel;
 use strict;
 use 5.012000;
-use version; our $VERSION = version->declare('v0.1.50');
+use version; our $VERSION = version->declare('v0.1.51');
 
 1;
 __END__
@@ -33,7 +33,7 @@ Carmel - CPAN Artifact Repository Manager
   carmel update
 
   # pin modules tp specific versions
-  carmel pin DBI@1.633 Plack@1.0000
+  carmel update DBI@1.633 Plack@1.0000
 
   # Runs your perl script with modules from artifacts
   carmel exec perl ...
